Blob Blame History Raw
--- orc-rel-release-1.6.6/cmake_modules/FindProtobuf.cmake.orig	2021-09-15 14:15:19.726344469 -0400
+++ orc-rel-release-1.6.6/cmake_modules/FindProtobuf.cmake	2021-09-15 14:16:22.330307272 -0400
@@ -15,8 +15,8 @@
 # PROTOBUF_FOUND is set if Protobuf is found
 # PROTOBUF_INCLUDE_DIR: directory containing headers
 # PROTOBUF_LIBS: directory containing Protobuf libraries
 # PROTOBUF_STATIC_LIB: location of protobuf.a
 # PROTOC_STATIC_LIB: location of protoc.a
 # PROTOBUF_EXECUTABLE: location of protoc
 
 
@@ -54,16 +54,16 @@
   get_filename_component (PROTOBUF_LIBS ${PROTOBUF_LIBRARY} PATH)
   set (PROTOBUF_LIB_NAME protobuf)
   set (PROTOC_LIB_NAME protoc)
-  set (PROTOBUF_STATIC_LIB ${PROTOBUF_LIBS}/${CMAKE_STATIC_LIBRARY_PREFIX}${PROTOBUF_LIB_NAME}${CMAKE_STATIC_LIBRARY_SUFFIX})
-  set (PROTOC_STATIC_LIB ${PROTOBUF_LIBS}/${CMAKE_STATIC_LIBRARY_PREFIX}${PROTOC_LIB_NAME}${CMAKE_STATIC_LIBRARY_SUFFIX})
+  set (PROTOBUF_SHARED_LIB ${PROTOBUF_LIBS}/${CMAKE_SHARED_LIBRARY_PREFIX}${PROTOBUF_LIB_NAME}${CMAKE_SHARED_LIBRARY_SUFFIX})
+  set (PROTOC_SHARED_LIB ${PROTOBUF_LIBS}/${CMAKE_SHARED_LIBRARY_PREFIX}${PROTOC_LIB_NAME}${CMAKE_SHARED_LIBRARY_SUFFIX})
 else ()
   set (PROTOBUF_FOUND FALSE)
 endif ()
 
 if (PROTOBUF_FOUND)
   message (STATUS "Found the Protobuf headers: ${PROTOBUF_INCLUDE_DIR}")
-  message (STATUS "Found the Protobuf library: ${PROTOBUF_STATIC_LIB}")
-  message (STATUS "Found the Protoc library: ${PROTOC_STATIC_LIB}")
+  message (STATUS "Found the Protobuf library: ${PROTOBUF_SHARED_LIB}")
+  message (STATUS "Found the Protoc library: ${PROTOC_SHARED_LIB}")
   message (STATUS "Found the Protoc executable: ${PROTOBUF_EXECUTABLE}")
 else()
   if (_protobuf_path)
@@ -82,6 +82,6 @@
 mark_as_advanced (
   PROTOBUF_INCLUDE_DIR
   PROTOBUF_LIBS
-  PROTOBUF_STATIC_LIB
-  PROTOC_STATIC_LIB
+  PROTOBUF_SHARED_LIB
+  PROTOC_SHARED_LIB
 )
@@ -15,8 +15,8 @@
 # PROTOBUF_INCLUDE_DIR: directory containing headers
 # PROTOBUF_LIBS: directory containing Protobuf libraries
-# PROTOBUF_STATIC_LIB: location of protobuf.a
-# PROTOC_STATIC_LIB: location of protoc.a
+# PROTOBUF_SHARED_LIB: location of protobuf.a
+# PROTOC_SHARED_LIB: location of protoc.a
 # PROTOBUF_EXECUTABLE: location of protoc
 